Module pel

Module pel 

PEL Parser Library

This module provides the function and types to parse a DataWeave expression into PEL.

Primary types

  • InputContext: Input context containing inputs (e.g. payload, attributes) and DW functions (e.g. substringBefore, fromBase64) for compiling the expression.
  • CompilationResult: Contains the compiled PEL expression if compile was successful or error messages upon failure.

Structs

CompilationResult
Contains the actual compilation result:
DeclaredNamespaces
InputContext
Sets the context to parse the DataWeave expression. It receives:
NamespaceInformation

Functions

compile_to_pel_expr
Compiles the provided DataWeave expression and returns a CompilationResult.