PEL Parser Library
This module provides the function and types to parse a DataWeave expression into PEL.
Primary types
InputContext: Input context containing inputs (e.g. payload, attributes) and DW functions (e.g. substringBefore, fromBase64) for compiling the expression.CompilationResult: Contains the compiled PEL expression if compile was successful or error messages upon failure.
Structs
- Compilation
Result - Contains the actual compilation result:
- Declared
Namespaces - Input
Context - Sets the context to parse the DataWeave expression. It receives:
- Namespace
Information
Functions
- compile_
to_ pel_ expr - Compiles the provided DataWeave expression and returns a CompilationResult.